# Generated by Django 2.2.25 on 2022-02-11 16:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("camomilla", "0006_auto_20220103_1845"),
    ]

    operations = [
        migrations.AlterField(
            model_name="articletranslation",
            name="permalink",
            field=models.SlugField(max_length=200),
        ),
    ]
