{% extends "admin/base.html" %}
{% load admin_static %}

{% block title %}{{ title }} | {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block branding %}
<img src='{% static "admin/img/logo.png" %}' class='logo'/>
{% endblock %}

{% block nav-global %}{% endblock %}

{% block bodyclass %}flat-theme{% endblock %}

{% block blockbots %}
  {{ block.super }}
  <meta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1.0, maximum-scale=1.0">
  <link rel="stylesheet" type="text/css" href="{% static "admin/css/responsive.css" %}" />
{% endblock %}
