# Generated by Django 2.2.25 on 2022-01-03 18:45

from django.db import migrations, models
from ..models import Media


def forwards_func(apps, schema_editor):
    db_alias = schema_editor.connection.alias
    for m in Media.objects.using(db_alias).all():
        m.save()


def reverse_func(apps, schema_editor):
    pass


class Migration(migrations.Migration):

    dependencies = [
        ("camomilla", "0005_media_image_props"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="media",
            name="is_image",
        ),
        migrations.AddField(
            model_name="media",
            name="mime_type",
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
        migrations.RunPython(forwards_func, reverse_func),
    ]
