# Generated by Django 2.2.17 on 2021-05-11 09:37

from django.db import migrations
import django.db.models.manager


class Migration(migrations.Migration):

    dependencies = [
        ("camomilla", "0003_auto_20210130_1610"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="article",
            managers=[
                ("objects", django.db.models.manager.Manager()),
                ("_plain_manager", django.db.models.manager.Manager()),
            ],
        ),
        migrations.RemoveField(
            model_name="article",
            name="trash",
        ),
    ]
